==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/iw.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'אדלם',
        'Aghb' => 'אלבני קווקזי',
        'Ahom' => 'אהום',
        'Arab' => 'ערבי',
        'Aran' => 'נסתעליק',
        'Armi' => 'ארמית רשמית',
        'Armn' => 'ארמני',
        'Avst' => 'אווסטן',
        'Bali' => 'באלינזי',
        'Bamu' => 'במום',
        'Bass' => 'באסה ואה',
        'Batk' => 'בטק',
        'Beng' => 'בנגלי',
        'Bhks' => 'בהיקסוקי',
        'Bopo' => 'בופומופו',
        'Brah' => 'ברהמי',
        'Brai' => 'ברייל',
        'Bugi' => 'בוגינזי',
        'Buhd' => 'בוהיד',
        'Cakm' => 'צ׳אקמה',
        'Cans' => 'סילביקה קדומה מאוחדת של קנדה',
        'Cari' => 'קריאן',
        'Cham' => 'צ׳אם',
        'Cher' => 'צ׳ירוקי',
        'Chrs' => 'כורזמיאן',
        'Copt' => 'קופטי',
        'Cpmn' => 'ציפרו-מינואן',
        'Cprt' => 'קפריסאי',
        'Cyrl' => 'קירילי',
        'Cyrs' => 'קירילי סלאבוני כנסייתי עתיק',
        'Deva' => 'דוואנגרי',
        'Diak' => 'אותיות אי',
        'Dogr' => 'דוגרה',
        'Dsrt' => 'דסרט',
        'Dupl' => 'קיצור של דובילרן',
        'Egyp' => 'כתב חרטומים',
        'Elba' => 'אלבסאן',
        'Elym' => 'אלימי',
        'Ethi' => 'אתיופי',
        'Geor' => 'גאורגי',
        'Glag' => 'גלגוליטי',
        'Gong' => 'ג’ונג’לה מבולבל',
        'Gonm' => 'מסארם גונדי',
        'Goth' => 'גותי',
        'Gran' => 'גרנתה',
        'Grek' => 'יווני',
        'Gujr' => 'גוג׳רטי',
        'Guru' => 'גורמוקי',
        'Hanb' => 'האן עם בופומופו',
        'Hang' => 'האנגול',
        'Hani' => 'האן',
        'Hano' => 'האנונו',
        'Hans' => 'פשוט',
        'Hant' => 'מסורתי',
        'Hatr' => 'חטרן',
        'Hebr' => 'עברי',
        'Hira' => 'הירגאנה',
        'Hluw' => 'הירוגליפים האנטוליים',
        'Hmng' => 'פאהח המונג',
        'Hmnp' => 'ניאקנג פואצ׳ה המונג',
        'Hrkt' => 'הברתי יפני',
        'Hung' => 'הונגרי עתיק',
        'Inds' => 'אינדוס',
        'Ital' => 'איטלקי עתיק',
        'Jamo' => 'ג׳אמו',
        'Java' => 'ג׳אוונזי',
        'Jpan' => 'יפני',
        'Kali' => 'קאי לי',
        'Kana' => 'קטקאנה',
        'Khar' => 'חרושתי',
        'Khmr' => 'חמרי',
        'Khoj' => 'חוג׳קי',
        'Kits' => 'כתב קטן של חיטן',
        'Knda' => 'קאנאדה',
        'Kore' => 'קוריאני',
        'Kthi' => 'קאיתי',
        'Lana' => 'לאנה',
        'Laoo' => 'לאי',
        'Latg' => 'לטיני גאלי',
        'Latn' => 'לטיני',
        'Lepc' => 'לפחה',
        'Limb' => 'לימבו',
        'Lina' => 'ליניארי א',
        'Linb' => 'ליניארי ב',
        'Lisu' => 'פרייזר',
        'Lyci' => 'ליקי',
        'Lydi' => 'לידי',
        'Mahj' => 'מהג׳אני',
        'Maka' => 'מקאסאר',
        'Mand' => 'מנדאית',
        'Mani' => 'מניצ׳י',
        'Marc' => 'מרצ׳ן',
        'Maya' => 'מאיה',
        'Medf' => 'מדפיידרין',
        'Mend' => 'מנדה',
        'Merc' => 'קורסית מרואיטית',
        'Mero' => 'מרואיטית',
        'Mlym' => 'מליאלאם',
        'Modi' => 'מודי',
        'Mong' => 'מונגולי',
        'Mroo' => 'מרו',
        'Mtei' => 'מאיטי מאייק',
        'Mult' => 'מולטיני',
        'Mymr' => 'מיאנמר',
        'Nand' => 'ננדינאגרי',
        'Narb' => 'ערב צפון עתיק',
        'Nbat' => 'נבטי',
        'Newa' => 'נווארית',
        'Nkoo' => 'נ׳קו',
        'Nshu' => 'נושו',
        'Ogam' => 'אוהם',
        'Olck' => 'אול צ׳יקי',
        'Orkh' => 'אורחון',
        'Orya' => 'אודייה',
        'Osge' => 'אוסייג׳',
        'Osma' => 'אוסמניה',
        'Ougr' => 'אוגורית ישנה',
        'Palm' => 'פלמירן',
        'Pauc' => 'פאו צ׳ין האו',
        'Perm' => 'פרמית ישנה',
        'Phag' => 'פאגס',
        'Phli' => 'פהלווי כתובתי',
        'Phlp' => 'מזמור פהלווי',
        'Phnx' => 'פיניקי',
        'Plrd' => 'פולארד פונטי',
        'Prti' => 'פרטית כתובה',
        'Qaag' => 'זאוגיי',
        'Rjng' => 'רג׳אנג',
        'Rohg' => 'חניפי',
        'Runr' => 'רוני',
        'Samr' => 'שומרונית',
        'Sarb' => 'דרום ערבית',
        'Saur' => 'סאוראשטרה',
        'Sgnw' => 'חתימה',
        'Shaw' => 'שבית',
        'Shrd' => 'שרדה',
        'Sidd' => 'סידהם',
        'Sind' => 'חודוואדי',
        'Sinh' => 'סינהלה',
        'Sogd' => 'סוגדית',
        'Sogo' => 'סוגדית עתיקה',
        'Sora' => 'סורה סומפנג',
        'Soyo' => 'סויומבו',
        'Sund' => 'סונדאנית',
        'Sylo' => 'סילוטי נגרי',
        'Syrc' => 'סורי',
        'Syrj' => 'סורי מערבי',
        'Syrn' => 'סורי מזרחי',
        'Tagb' => 'טגבנווה',
        'Takr' => 'טאקרי',
        'Tale' => 'טאי לה',
        'Talu' => 'טאי ליו חדש',
        'Taml' => 'טמיל',
        'Tang' => 'טאנגוט',
        'Tavt' => 'טאי וייט',
        'Telu' => 'טלוגו',
        'Tfng' => 'טיפינה',
        'Tglg' => 'טגלוג',
        'Thaa' => 'תאנה',
        'Thai' => 'תאי',
        'Tibt' => 'טיבטי',
        'Tirh' => 'תרותא',
        'Tnsa' => 'טנגסה',
        'Toto' => 'טוטו',
        'Ugar' => 'אוגריתי',
        'Vaii' => 'ואי',
        'Vith' => 'ויטוקוקי',
        'Wara' => 'ווראנג סיטי',
        'Wcho' => 'וונצ׳ו',
        'Xpeo' => 'פרסי עתיק',
        'Xsux' => 'כתב היתדות השומרי-אכדי',
        'Yezi' => 'יעזי',
        'Yiii' => 'יי',
        'Zanb' => 'כיכר זנבזר',
        'Zinh' => 'מורש',
        'Zmth' => 'סימון מתמטי',
        'Zsye' => 'אמוג׳י',
        'Zsym' => 'סמלים',
        'Zxxx' => 'לא כתוב',
        'Zyyy' => 'רגיל',
    ],
];

==> symfony_7.4.0+dfsg.orig.tar.xz: symfony-7.4.0/src/Symfony/Component/Intl/Resources/data/scripts/iw.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'אדלם',
        'Aghb' => 'אלבני קווקזי',
        'Ahom' => 'אהום',
        'Arab' => 'ערבי',
        'Aran' => 'נסתעליק',
        'Armi' => 'ארמית רשמית',
        'Armn' => 'ארמני',
        'Avst' => 'אווסטן',
        'Bali' => 'באלינזי',
        'Bamu' => 'במום',
        'Bass' => 'באסה ואה',
        'Batk' => 'בטק',
        'Beng' => 'בנגלי',
        'Bhks' => 'בהיקסוקי',
        'Bopo' => 'בופומופו',
        'Brah' => 'ברהמי',
        'Brai' => 'ברייל',
        'Bugi' => 'בוגינזי',
        'Buhd' => 'בוהיד',
        'Cakm' => 'צ׳אקמה',
        'Cans' => 'כתב הברתי קנדי ילידי מאוחד',
        'Cari' => 'קריאן',
        'Cham' => 'צ׳אם',
        'Cher' => 'צ׳רוקי',
        'Chrs' => 'כורזמיאן',
        'Copt' => 'קופטי',
        'Cpmn' => 'ציפרו-מינואן',
        'Cprt' => 'קפריסאי',
        'Cyrl' => 'קירילי',
        'Cyrs' => 'קירילי סלאבוני כנסייתי עתיק',
        'Deva' => 'דוואנגרי',
        'Diak' => 'אותיות אי',
        'Dogr' => 'דוגרה',
        'Dsrt' => 'דסרט',
        'Dupl' => 'קיצור של דובילרן',
        'Egyp' => 'כתב חרטומים',
        'Elba' => 'אלבסאן',
        'Elym' => 'אלימי',
        'Ethi' => 'אתיופי',
        'Geor' => 'גאורגי',
        'Glag' => 'גלגוליטי',
        'Gong' => 'ג’ונג’לה מבולבל',
        'Gonm' => 'מסארם גונדי',
        'Goth' => 'גותי',
        'Gran' => 'גרנתה',
        'Grek' => 'יווני',
        'Gujr' => 'גוג׳רטי',
        'Guru' => 'גורמוקי',
        'Hanb' => 'האן עם בופומופו',
        'Hang' => 'האנגול',
        'Hani' => 'האן',
        'Hano' => 'האנונו',
        'Hans' => 'פשוט',
        'Hant' => 'מסורתי',
        'Hatr' => 'חטרן',
        'Hebr' => 'עברי',
        'Hira' => 'הירגאנה',
        'Hluw' => 'הירוגליפים האנטוליים',
        'Hmng' => 'פאהח המונג',
        'Hmnp' => 'ניאקנג פואצ׳ה המונג',
        'Hrkt' => 'הברתי יפני',
        'Hung' => 'הונגרי עתיק',
        'Inds' => 'אינדוס',
        'Ital' => 'איטלקי עתיק',
        'Jamo' => 'ג׳אמו',
        'Java' => 'ג׳אוונזי',
        'Jpan' => 'יפני',
        'Kali' => 'קאי לי',
        'Kana' => 'קטקאנה',
        'Khar' => 'חרושתי',
        'Khmr' => 'חמרי',
        'Khoj' => 'חוג׳קי',
        'Kits' => 'כתב קטן של חיטן',
        'Knda' => 'קאנאדה',
        'Kore' => 'קוריאני',
        'Kthi' => 'קאיתי',
        'Lana' => 'לאנה',
        'Laoo' => 'לאי',
        'Latg' => 'לטיני גאלי',
        'Latn' => 'לטיני',
        'Lepc' => 'לפחה',
        'Limb' => 'לימבו',
        'Lina' => 'ליניארי א',
        'Linb' => 'ליניארי ב',
        'Lisu' => 'פרייזר',
        'Lyci' => 'ליקי',
        'Lydi' => 'לידי',
        'Mahj' => 'מהג׳אני',
        'Maka' => 'מקאסאר',
        'Mand' => 'מנדאית',
        'Mani' => 'מניצ׳י',
        'Marc' => 'מרצ׳ן',
        'Maya' => 'מאיה',
        'Medf' => 'מדפיידרין',
        'Mend' => 'מנדה',
        'Merc' => 'קורסית מרואיטית',
        'Mero' => 'מרואיטית',
        'Mlym' => 'מליאלאם',
        'Modi' => 'מודי',
        'Mong' => 'מונגולי',
        'Mroo' => 'מרו',
        'Mtei' => 'מאיטי מאייק',
        'Mult' => 'מולטיני',
        'Mymr' => 'מיאנמר',
        'Nand' => 'ננדינאגרי',
        'Narb' => 'ערב צפון עתיק',
        'Nbat' => 'נבטי',
        'Newa' => 'נווארית',
        'Nkoo' => 'נ׳קו',
        'Nshu' => 'נושו',
        'Ogam' => 'אוהם',
        'Olck' => 'אול צ׳יקי',
        'Orkh' => 'אורחון',
        'Orya' => 'אודייה',
        'Osge' => 'אוסייג׳',
        'Osma' => 'אוסמניה',
        'Ougr' => 'אוגורית ישנה',
        'Palm' => 'פלמירן',
        'Pauc' => 'פאו צ׳ין האו',
        'Perm' => 'פרמית ישנה',
        'Phag' => 'פאגס',
        'Phli' => 'פהלווי כתובתי',
        'Phlp' => 'מזמור פהלווי',
        'Phnx' => 'פיניקי',
        'Plrd' => 'פולארד פונטי',
        'Prti' => 'פרטית כתובה',
        'Qaag' => 'זאוגיי',
        'Rjng' => 'רג׳אנג',
        'Rohg' => 'חניפי',
        'Runr' => 'רוני',
        'Samr' => 'שומרונית',
        'Sarb' => 'דרום ערבית',
        'Saur' => 'סאוראשטרה',
        'Sgnw' => 'חתימה',
        'Shaw' => 'שבית',
        'Shrd' => 'שרדה',
        'Sidd' => 'סידהם',
        'Sind' => 'חודוואדי',
        'Sinh' => 'סינהלה',
        'Sogd' => 'סוגדית',
        'Sogo' => 'סוגדית עתיקה',
        'Sora' => 'סורה סומפנג',
        'Soyo' => 'סויומבו',
        'Sund' => 'סונדאני',
        'Sylo' => 'סילוטי נגרי',
        'Syrc' => 'סורי',
        'Syrj' => 'סורי מערבי',
        'Syrn' => 'סורי מזרחי',
        'Tagb' => 'טגבנווה',
        'Takr' => 'טאקרי',
        'Tale' => 'טאי לה',
        'Talu' => 'טאי ליו חדש',
        'Taml' => 'טמיל',
        'Tang' => 'טאנגוט',
        'Tavt' => 'טאי וייט',
        'Telu' => 'טלוגו',
        'Tfng' => 'טיפינה',
        'Tglg' => 'טגלוג',
        'Thaa' => 'תאנה',
        'Thai' => 'תאי',
        'Tibt' => 'טיבטי',
        'Tirh' => 'תרותא',
        'Tnsa' => 'טנגסה',
        'Toto' => 'טוטו',
        'Ugar' => 'אוגריתי',
        'Vaii' => 'ואי',
        'Vith' => 'ויטוקוקי',
        'Wara' => 'ווראנג סיטי',
        'Wcho' => 'וונצ׳ו',
        'Xpeo' => 'פרסי עתיק',
        'Xsux' => 'כתב היתדות השומרי-אכדי',
        'Yezi' => 'יעזי',
        'Yiii' => 'יי',
        'Zanb' => 'כיכר זנבזר',
        'Zinh' => 'מורש',
        'Zmth' => 'סימון מתמטי',
        'Zsye' => 'אמוג׳י',
        'Zsym' => 'סמלים',
        'Zxxx' => 'לא כתוב',
        'Zyyy' => 'רגיל',
    ],
];
